@@ -4,6 +4,7 @@ from ama_xiv_combat_sim.simulator.calcs.damage_class import DamageClass
 from ama_xiv_combat_sim.simulator.game_data.patch_655.convenience_timings import (
     get_auto_timing,
 )
+from ama_xiv_combat_sim.simulator.game_data.game_consts import GameConsts
 from ama_xiv_combat_sim.simulator.sim_consts import SimConsts
 from ama_xiv_combat_sim.simulator.skills.skill import Skill
 from ama_xiv_combat_sim.simulator.specs.damage_spec import DamageSpec
@@ -17,7 +18,8 @@ from ama_xiv_combat_sim.simulator.specs.timing_spec import TimingSpec
 def add_blm_skills(skill_library):
     auto_timing = get_auto_timing()
     blm_caster_tax_ms = 100
-    instant_timing_spec = TimingSpec(base_cast_time=0, animation_lock=blm_caster_tax_ms)
+    base_animation_lock = 600
+    instant_timing_spec = TimingSpec(base_cast_time=0, animation_lock=base_animation_lock)
     skill_library.set_current_job_class("BLM")
 
     skill_library.set_status_effect_priority(("Swiftcast", "Triplecast"))
@@ -138,10 +140,14 @@ def add_blm_skills(skill_library):
             "2 Umbral Ice": 1,
             "3 Umbral Ice": 1,
         }
-
+        animation_lock_overflow = max(
+            0,
+            base_animation_lock
+            - min(base_cast_time, GameConsts.DAMAGE_SNAPSHOT_TIME_BEFORE_CAST_FINISHES),
+        )
         res[SimConsts.DEFAULT_CONDITION] = TimingSpec(
             base_cast_time=base_cast_time,
-            animation_lock=blm_caster_tax_ms,
+            animation_lock=animation_lock_overflow,
             application_delay=application_delay,
         )
         for elem_str in elem_strs:
@@ -150,9 +156,17 @@ def add_blm_skills(skill_library):
                 if is_fire_spell
                 else ice_cast_time_modifiers[elem_str]
             )
+            animation_lock_overflow = max(
+                0,
+                base_animation_lock
+                - min(
+                    int(cast_modifier * base_cast_time),
+                    GameConsts.DAMAGE_SNAPSHOT_TIME_BEFORE_CAST_FINISHES,
+                ),
+            )
             res[elem_str] = TimingSpec(
                 base_cast_time=int(cast_modifier * base_cast_time),
-                animation_lock=blm_caster_tax_ms,
+                animation_lock=animation_lock_overflow,
                 application_delay=application_delay,
             )
         return res
@@ -413,7 +427,7 @@ def add_blm_skills(skill_library):
             },
             timing_spec=TimingSpec(
                 base_cast_time=0,
-                animation_lock=blm_caster_tax_ms,
+                animation_lock=base_animation_lock,
                 application_delay=670,
             ),
         )
@@ -434,7 +448,7 @@ def add_blm_skills(skill_library):
         )
         fire_iii_damage_spec[assembled_str] = fire_iii_damage_spec[k]
         fire_iii_timing_spec[assembled_str] = TimingSpec(
-            base_cast_time=0, animation_lock=blm_caster_tax_ms, application_delay=1290
+            base_cast_time=0, animation_lock=base_animation_lock, application_delay=1290
         )
     skill_library.add_skill(
         Skill(
@@ -501,7 +515,7 @@ def add_blm_skills(skill_library):
                 ),
                 "Thundercloud": TimingSpec(
                     base_cast_time=0,
-                    animation_lock=blm_caster_tax_ms,
+                    animation_lock=base_animation_lock,
                     application_delay=1030,
                 ),
             },
@@ -641,7 +655,7 @@ def add_blm_skills(skill_library):
             damage_spec=DamageSpec(potency=600),
             timing_spec=TimingSpec(
                 base_cast_time=0,
-                animation_lock=blm_caster_tax_ms,
+                animation_lock=base_animation_lock,
                 application_delay=1160,
             ),
         )
@@ -674,7 +688,7 @@ def add_blm_skills(skill_library):
             damage_spec=DamageSpec(potency=880),
             timing_spec=TimingSpec(
                 base_cast_time=0,
-                animation_lock=blm_caster_tax_ms,
+                animation_lock=base_animation_lock,
                 application_delay=620,
             ),
         )
@@ -725,7 +739,7 @@ def add_blm_skills(skill_library):
         base_cast_time=2500, animation_lock=blm_caster_tax_ms, application_delay=670
     )
     paradox_umbral_timing_spec = TimingSpec(
-        base_cast_time=0, animation_lock=blm_caster_tax_ms, application_delay=670
+        base_cast_time=0, animation_lock=base_animation_lock, application_delay=670
     )
     skill_library.add_skill(
         Skill(
