@@ -19,7 +19,7 @@ def add_pct_skills(skill_library):
     pct_caster_tax_ms = 100
     base_animation_lock = 600
     instant_timing_spec = TimingSpec(
-        base_cast_time=0, animation_lock=base_animation_lock + pct_caster_tax_ms
+        base_cast_time=0, animation_lock=base_animation_lock
     )
     skill_library.set_current_job_class("PCT")
 
@@ -92,7 +92,7 @@ def add_pct_skills(skill_library):
             damage_spec=DamageSpec(potency=440),
             timing_spec=TimingSpec(
                 base_cast_time=1500,
-                animation_lock=base_animation_lock + pct_caster_tax_ms,
+                animation_lock= pct_caster_tax_ms,
                 application_delay=650,
             ),
             job_resource_spec=(JobResourceSpec(name="Hyperphantasia", change=-1),),
@@ -109,7 +109,7 @@ def add_pct_skills(skill_library):
             damage_spec=DamageSpec(potency=480),
             timing_spec=TimingSpec(
                 base_cast_time=1500,
-                animation_lock=base_animation_lock + pct_caster_tax_ms,
+                animation_lock= pct_caster_tax_ms,
                 application_delay=650,
             ),
             job_resource_spec=(JobResourceSpec(name="Hyperphantasia", change=-1),),
@@ -126,7 +126,7 @@ def add_pct_skills(skill_library):
             damage_spec=DamageSpec(potency=520),
             timing_spec=TimingSpec(
                 base_cast_time=1500,
-                animation_lock=base_animation_lock + pct_caster_tax_ms,
+                animation_lock= pct_caster_tax_ms,
                 application_delay=650,
             ),
             job_resource_spec=(JobResourceSpec(name="Hyperphantasia", change=-1),),
@@ -144,7 +144,7 @@ def add_pct_skills(skill_library):
             damage_spec=DamageSpec(potency=120),
             timing_spec=TimingSpec(
                 base_cast_time=1500,
-                animation_lock=base_animation_lock + pct_caster_tax_ms,
+                animation_lock= pct_caster_tax_ms,
                 application_delay=650,
             ),
             job_resource_spec=(JobResourceSpec(name="Hyperphantasia", change=-1),),
@@ -161,7 +161,7 @@ def add_pct_skills(skill_library):
             damage_spec=DamageSpec(potency=1300),
             timing_spec=TimingSpec(
                 base_cast_time=0,
-                animation_lock=base_animation_lock + pct_caster_tax_ms,
+                animation_lock=base_animation_lock,
                 application_delay=650,
             ),
         )
@@ -173,7 +173,7 @@ def add_pct_skills(skill_library):
             damage_spec=DamageSpec(potency=1100),
             timing_spec=TimingSpec(
                 base_cast_time=0,
-                animation_lock=base_animation_lock + pct_caster_tax_ms,
+                animation_lock=base_animation_lock,
                 application_delay=650,
             ),
         )
@@ -185,7 +185,7 @@ def add_pct_skills(skill_library):
             damage_spec=DamageSpec(potency=1100),
             timing_spec=TimingSpec(
                 base_cast_time=0,
-                animation_lock=base_animation_lock + pct_caster_tax_ms,
+                animation_lock=base_animation_lock,
                 application_delay=650,
             ),
         )
@@ -197,7 +197,7 @@ def add_pct_skills(skill_library):
             damage_spec=DamageSpec(potency=140),
             timing_spec=TimingSpec(
                 base_cast_time=1500,
-                animation_lock=base_animation_lock + pct_caster_tax_ms,
+                animation_lock= pct_caster_tax_ms,
                 application_delay=650,
             ),
             job_resource_spec=(JobResourceSpec(name="Hyperphantasia", change=-1),),
@@ -214,7 +214,7 @@ def add_pct_skills(skill_library):
             damage_spec=DamageSpec(potency=160),
             timing_spec=TimingSpec(
                 base_cast_time=1500,
-                animation_lock=base_animation_lock + pct_caster_tax_ms,
+                animation_lock= pct_caster_tax_ms,
                 application_delay=650,
             ),
             job_resource_spec=(JobResourceSpec(name="Hyperphantasia", change=-1),),
@@ -235,7 +235,7 @@ def add_pct_skills(skill_library):
             ),
             timing_spec=TimingSpec(
                 base_cast_time=0,
-                animation_lock=base_animation_lock + pct_caster_tax_ms,
+                animation_lock=base_animation_lock,
                 application_delay=650,
             ),
         )
@@ -247,7 +247,7 @@ def add_pct_skills(skill_library):
             damage_spec=DamageSpec(potency=800),
             timing_spec=TimingSpec(
                 base_cast_time=2300,
-                animation_lock=base_animation_lock + pct_caster_tax_ms,
+                animation_lock= pct_caster_tax_ms,
                 application_delay=650,
                 gcd_base_recast_time=3300,
             ),
@@ -265,7 +265,7 @@ def add_pct_skills(skill_library):
             damage_spec=DamageSpec(potency=240),
             timing_spec=TimingSpec(
                 base_cast_time=2300,
-                animation_lock=base_animation_lock + pct_caster_tax_ms,
+                animation_lock= pct_caster_tax_ms,
                 application_delay=650,
                 gcd_base_recast_time=3300,
             ),
@@ -283,7 +283,7 @@ def add_pct_skills(skill_library):
             damage_spec=DamageSpec(potency=840),
             timing_spec=TimingSpec(
                 base_cast_time=2300,
-                animation_lock=base_animation_lock + pct_caster_tax_ms,
+                animation_lock= pct_caster_tax_ms,
                 application_delay=650,
                 gcd_base_recast_time=3300,
             ),
@@ -301,7 +301,7 @@ def add_pct_skills(skill_library):
             damage_spec=DamageSpec(potency=880),
             timing_spec=TimingSpec(
                 base_cast_time=2300,
-                animation_lock=base_animation_lock + pct_caster_tax_ms,
+                animation_lock= pct_caster_tax_ms,
                 application_delay=650,
                 gcd_base_recast_time=3300,
             ),
@@ -319,7 +319,7 @@ def add_pct_skills(skill_library):
             damage_spec=DamageSpec(potency=260),
             timing_spec=TimingSpec(
                 base_cast_time=2300,
-                animation_lock=base_animation_lock + pct_caster_tax_ms,
+                animation_lock= pct_caster_tax_ms,
                 application_delay=650,
                 gcd_base_recast_time=3300,
             ),
@@ -337,7 +337,7 @@ def add_pct_skills(skill_library):
             damage_spec=DamageSpec(potency=280),
             timing_spec=TimingSpec(
                 base_cast_time=2300,
-                animation_lock=base_animation_lock + pct_caster_tax_ms,
+                animation_lock= pct_caster_tax_ms,
                 application_delay=650,
                 gcd_base_recast_time=3300,
             ),
@@ -353,7 +353,7 @@ def add_pct_skills(skill_library):
         Skill(
             name="Starry Muse",
             is_GCD=False,
-            timing_spec=TimingSpec(base_cast_time=0, animation_lock=base_animation_lock + pct_caster_tax_ms),
+            timing_spec=TimingSpec(base_cast_time=0, animation_lock=base_animation_lock),
             buff_spec={
                 SimConsts.DEFAULT_CONDITION: StatusEffectSpec(
                     damage_mult=1.05, duration=int(20.35 * 1000), is_party_effect=True
@@ -381,7 +381,7 @@ def add_pct_skills(skill_library):
             damage_spec=DamageSpec(potency=520),
             timing_spec=TimingSpec(
                 base_cast_time=0,
-                animation_lock=base_animation_lock + pct_caster_tax_ms,
+                animation_lock=base_animation_lock,
                 application_delay=650,
             ),
             job_resource_spec=(JobResourceSpec(name="Hyperphantasia", change=-1),),
@@ -402,7 +402,7 @@ def add_pct_skills(skill_library):
             ),
             timing_spec=TimingSpec(
                 base_cast_time=0,
-                animation_lock=base_animation_lock + pct_caster_tax_ms,
+                animation_lock=base_animation_lock,
                 application_delay=650,
             ),
         )
@@ -418,7 +418,7 @@ def add_pct_skills(skill_library):
             ),
             timing_spec=TimingSpec(
                 base_cast_time=0,
-                animation_lock=base_animation_lock + pct_caster_tax_ms,
+                animation_lock=base_animation_lock,
                 application_delay=650,
             ),
         )
@@ -430,7 +430,7 @@ def add_pct_skills(skill_library):
             damage_spec=DamageSpec(potency=880),
             timing_spec=TimingSpec(
                 base_cast_time=0,
-                animation_lock=base_animation_lock + pct_caster_tax_ms,
+                animation_lock=base_animation_lock,
                 application_delay=650,
                 gcd_base_recast_time=3300,
             ),
@@ -449,13 +449,13 @@ def add_pct_skills(skill_library):
             timing_spec={
                 SimConsts.DEFAULT_CONDITION: TimingSpec(
                     base_cast_time=4000,
-                    animation_lock=base_animation_lock + pct_caster_tax_ms,
+                    animation_lock= pct_caster_tax_ms,
                     application_delay=650,
                     gcd_base_recast_time=6000,
                 ),
                 "Rainbow Bright": TimingSpec(
                     base_cast_time=0,
-                    animation_lock=base_animation_lock + pct_caster_tax_ms,
+                    animation_lock=base_animation_lock,
                     application_delay=650,
                     gcd_base_recast_time=int(0.4 * 6000),  # 60% reduction?
                 ),
@@ -469,7 +469,7 @@ def add_pct_skills(skill_library):
             damage_spec=DamageSpec(potency=1100),
             timing_spec=TimingSpec(
                 base_cast_time=0,
-                animation_lock=base_animation_lock + pct_caster_tax_ms,
+                animation_lock=base_animation_lock,
                 application_delay=650,
             ),
         )
@@ -481,7 +481,7 @@ def add_pct_skills(skill_library):
             damage_spec=DamageSpec(potency=1100),
             timing_spec=TimingSpec(
                 base_cast_time=0,
-                animation_lock=base_animation_lock + pct_caster_tax_ms,
+                animation_lock=base_animation_lock,
                 application_delay=650,
             ),
         )
@@ -493,7 +493,7 @@ def add_pct_skills(skill_library):
             damage_spec=DamageSpec(potency=1400),
             timing_spec=TimingSpec(
                 base_cast_time=0,
-                animation_lock=base_animation_lock + pct_caster_tax_ms,
+                animation_lock=base_animation_lock,
                 application_delay=650,
             ),
         )
@@ -505,7 +505,7 @@ def add_pct_skills(skill_library):
             damage_spec=DamageSpec(potency=1400),
             timing_spec=TimingSpec(
                 base_cast_time=0,
-                animation_lock=base_animation_lock + pct_caster_tax_ms,
+                animation_lock=base_animation_lock,
                 application_delay=1250,
             ),
             job_resource_spec=(JobResourceSpec(name="Hyperphantasia", change=-1),),
